%% TARGETS
utarget           = 0.0946;                           % ss target: unemployment
qtarget           = 0.6;                              % ss target: probability of filling a vacancy
vcrate            = 0.13;                             % ss target: hiring cost over wage
rhotottarget      = 0.036;                            % ss target: total separation rate
exoseptarget      = 0.71;                             % ss target: fraction of jobs exogenously separated;
firmexotarget     = 0.25;                             % ss target: JD due to firm exit
feregrateP        = 0.69;                             % ss target: share of per-capita gdp spent on regulaiton
fetechtarget      = 0.65;                             % ss target: R&D expenditure at firm level;
markuptarget      = 1.1;                              % ss target: markup


% labor market parameters
etaP              = 0.6;                              % worker's bargaining power
epsP              = etaP;                             % matching function (elasticity of UNEMPLOYMENT);
rrRateP           = 0.62;                             % replacement rate

%% preferences %%%%%%%%%
betaP             = 0.989;                            % discount rate
gammaP            = 1;                                % intertemporal elasticity of substitution

%% entry parameters
NbarP             = 100;                              % maximum number of potential varieties

% capital
alphaP            = 0.33;                             % capital share in the production function
adjIP             = 1.5;                              % size of investment adjustment costs
shapeP            = 1;                                % exponent of idiosyncratic productivity shock in individual production function 
exponenpfP        = shapeP/(1 - alphaP);              % exponent of zc in marhinal producuct of marginal worker
deltakP           = 0.025;                            % capital depreciation


% aggregate and idiosyncratic shocks
meanziP           = 0;                                % mean of lognormal distribution
stdziP            = 0.147;                            % std deviation of idiosyncratic shocks
stdzP             = 0.0099;                           % standard deviation of technology shock;
rhozP             = 0.983;                            % persistence of aggregate productivity shocks

load options
if momentsI==0
    rhozP = 0.9;
end

% Policy parameters in Flex Economy
rrRateFlex        = 0.5695;                           % replecement rate as a fraction of steady state wage
fcRateFlex        = 0;                                % firing costs as a fraction of steady state wage
feregtargetFlex   = 0.18;                             % entry cost as a fraction of per capita output
save policyTargets rrRateFlex fcRateFlex feregtargetFlex


piP               = pi;                               % pi greek
    
    
options = optimset('Display','off','MaxIter', 5000,'MaxFunEvals',5000,'TolFun', 1.0000e-14,'TolX', 1.0000e-14);
x0 = [1,2,1,.2,0.05]; 

[steadySol,fval] = fsolve(@(x) calibration_solver(x,utarget,qtarget,rhotottarget,rrRateP,etaP,betaP,meanziP,stdziP,alphaP,feregrateP,firmexotarget,NbarP,deltakP,fetechtarget,exoseptarget,shapeP,exponenpfP,piP,vcrate,markuptarget),x0,options);


w_SS                 = real(steadySol(1));
N_SS                 = real(steadySol(2));
hpP                  = real(steadySol(3));
c_SS                 = real(steadySol(4));
fcP                  = real(steadySol(5));



if max(abs(fval)) > 1e-10
    display('Inaccurate initial steady state')
    disp([' fval = ' num2str(max(abs(fval)),'%.4f') ]);
    keyboard
end

if min(steadySol) < 0
    display('Zero or negative initial steady-state values')    
    keyboard
end

q_SS                 = qtarget;
deltafP              = firmexotarget*rhotottarget/(1 + firmexotarget*rhotottarget); 
lambdaP              = exoseptarget*(1-deltafP)*rhotottarget;                       
z_SS                 = 1;
markup_SS            = markuptarget;
u_SS                 = utarget;
rho_SS               = 1 - 1/((1-lambdaP)*(1-deltafP)*(1 + rhotottarget));


if rho_SS<0 || lambdaP<0 || deltafP <0
    display('targets imply negative probabilities')
    disp([' rho_SS  = ' num2str(rho_SS,'%.8f') ]);
    disp([' deltafP = ' num2str(deltafP,'%.8f') ]);
    disp([' lambdaP = ' num2str(lambdaP,'%.8f') ]);
    keyboard
end

Ne_SS                = (deltafP/(1-deltafP))*N_SS;
sigmaMuP             = 1/(N_SS*(markup_SS - 1));
rpD_SS               = exp(-0.5*(NbarP-N_SS)/(sigmaMuP*NbarP*N_SS));
mc_SS                = rpD_SS/markup_SS;
ubP                  = rrRateP*w_SS/rpD_SS;
vcP                  = vcrate*w_SS*q_SS;
zc_SS                = icdf('lognormal', rho_SS , meanziP , stdziP);
zavInt_SS            = (-1/2*piP^(1/2)*exp(1/2*(2*meanziP+stdziP^2*shapeP)*shapeP/(1-2*alphaP+alphaP^2))*(erf(1/2*2^(1/2)/stdziP*(-log(zc_SS)+log(zc_SS)*alphaP+stdziP^2*shapeP+meanziP-meanziP*alphaP)/(-1+alphaP))-erf(1/2*2^(1/2)*(-10000000000+10000000000*alphaP+stdziP^2*shapeP+meanziP-meanziP*alphaP)/stdziP/(-1+alphaP)))*exp(-shapeP*meanziP*alphaP/(-1+alphaP)^2)/piP^(1/2))/(1-rho_SS);
zav_SS               = zavInt_SS^(1/exponenpfP);
l_SS                 = 1 - u_SS;
m_SS                 = rhotottarget*l_SS;
v_SS                 = m_SS/q_SS;
s_SS                 = m_SS/u_SS;
k_SS                 =((1/betaP - (1 - deltakP))/(alphaP*mc_SS*z_SS*(zav_SS^shapeP)*(l_SS^(1-alphaP))))^(1/(alphaP-1));
yn_SS                = z_SS*(zav_SS^shapeP)*(k_SS^alphaP)*(l_SS^(1-alphaP));
mpl_SS               = (1 - alphaP)*mc_SS*yn_SS/l_SS;
mplzc_SS             = mpl_SS*((zc_SS/zav_SS)^exponenpfP);
wzc_SS               = w_SS - etaP*(mpl_SS - mplzc_SS); 
phi_SS               = mpl_SS + vcP/q_SS - (etaP*(mpl_SS + vcP*(s_SS/q_SS)) + (1-etaP)*(ubP + hpP) + (etaP*(1 - (1-lambdaP)*(1-deltafP)*(1-s_SS)*betaP)*fcP));
lfirm_SS             = l_SS/N_SS;
vfirm_SS             = (v_SS - Ne_SS*lfirm_SS/q_SS)/(N_SS + Ne_SS);
mpk_SS               = alphaP*mc_SS*yn_SS/k_SS;
kfirm_SS             = k_SS/N_SS;
yfirm_SS             = yn_SS/N_SS;
y_SS                 = rpD_SS*yfirm_SS*N_SS;
cm_SS                = c_SS - hpP*(1-l_SS);
ik_SS                = deltakP*k_SS;
fetechP              = fetechtarget*yn_SS;
fr_SS                = feregrateP*yn_SS;
fe_SS                = fetechP + fr_SS;
d_SS                 = rpD_SS*yfirm_SS - mpk_SS*kfirm_SS - vcP*vfirm_SS - rho_SS*lfirm_SS*fcP/(1-rho_SS)  - lfirm_SS*w_SS;
e_SS                 = fe_SS + vcP*(lfirm_SS/q_SS + vfirm_SS);
firing_SS            = etaP*(1 - (1-lambdaP)*(1-deltafP)*(1-s_SS)*betaP)*fcP;



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% ADITIONAL VARIABLES/PARAMETERS 
chiP                 = m_SS/((v_SS^(1-epsP))*(u_SS^(epsP)));
uc_SS                = c_SS^-gammaP;
elasticity_SS        = 1 + sigmaMuP*N_SS;
surplusF_SS          = phi_SS + fcP;
surplusW_SS          = (etaP/(1-etaP))*surplusF_SS;
oo_SS                = hpP + ubP + s_SS*(1-lambdaP)*(1-deltafP)*betaP*(1-rho_SS)*surplusW_SS;
ub_SS                = ubP;
fc_SS                = fcP;
rk_SS                = mpk_SS;
phizc_SS             = mplzc_SS - wzc_SS + (1-lambdaP)*(1-deltafP)*(betaP)*( (1-rho_SS)*phi_SS - rho_SS*fc_SS ); 
surplusWzc_SS        = wzc_SS - oo_SS + (1-lambdaP)*(1-deltafP)*(betaP)*(1-rho_SS)*surplusW_SS; 
surplusFzc_SS        = phizc_SS + fc_SS;
multR_SS             = 1;
adjI_SS              = 0;
itot_SS              = ik_SS + Ne_SS*e_SS;
gdpIncome_SS         = w_SS*l_SS + rk_SS*k_SS + N_SS*d_SS;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
save calibration gammaP betaP rhozP stdzP lambdaP etaP epsP meanziP stdziP alphaP piP adjIP deltafP  NbarP sigmaMuP chiP vcP fetechP deltakP shapeP exponenpfP fetechtarget...
                 rrRateP hpP feregrateP;

save steady      z_SS c_SS l_SS q_SS m_SS s_SS u_SS v_SS w_SS mc_SS rho_SS zav_SS zc_SS wzc_SS phi_SS ...
                 surplusF_SS surplusW_SS y_SS ub_SS fc_SS fr_SS ik_SS k_SS mpl_SS mpk_SS rk_SS oo_SS  multR_SS adjI_SS ub_SS fc_SS ubP...
                 e_SS d_SS N_SS Ne_SS rpD_SS elasticity_SS markup_SS yfirm_SS yn_SS...
                 vfirm_SS lfirm_SS kfirm_SS mplzc_SS wzc_SS phizc_SS surplusFzc_SS surplusWzc_SS uc_SS...
                 cm_SS itot_SS gdpIncome_SS zavInt_SS;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% save initial values
 clear all; load steady;
 variables_list = cellstr(who);
 for i_index = 1: length(variables_list)
     varname = genvarname([variables_list{i_index},'init']);
     eval([varname '= ',[variables_list{i_index}],';']);               
 end

savefile = 'steadyInitial';
save(savefile, '*_SSinit')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        
            
             
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% SAVE GUESS VALUES FOR NEW STEADY STATE
c0 = c_SS; k0 = k_SS; w0 = w_SS; zc0 = zc_SS; q0 = q_SS; l0 = l_SS; N0 = N_SS;
save guess c0 k0 w0 zc0 q0 l0 N0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

